summaryrefslogtreecommitdiff
path: root/libavformat/avio.h
diff options
context:
space:
mode:
authorAnton Khirnov <anton@khirnov.net>2011-03-17 08:13:34 +0100
committerAnton Khirnov <anton@khirnov.net>2011-04-03 22:46:56 +0200
commitb92c5452822f9f58d33daf933a0d2a5516866bc1 (patch)
tree8e837202fc801d8f0de5e8be08b691a7d357cde9 /libavformat/avio.h
parent8978fedaeefdff50ed4deefbfe822ad07f19f616 (diff)
avio: avio_ prefix for url_open_dyn_buf
Diffstat (limited to 'libavformat/avio.h')
-rw-r--r--libavformat/avio.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/libavformat/avio.h b/libavformat/avio.h
index 80446b4808..9e21057b85 100644
--- a/libavformat/avio.h
+++ b/libavformat/avio.h
@@ -447,6 +447,7 @@ attribute_deprecated int url_fprintf(AVIOContext *s, const char *fmt, ...) __att
attribute_deprecated int url_fprintf(AVIOContext *s, const char *fmt, ...);
#endif
attribute_deprecated void put_flush_packet(AVIOContext *s);
+attribute_deprecated int url_open_dyn_buf(AVIOContext **s);
/**
* @}
*/
@@ -680,7 +681,7 @@ attribute_deprecated int url_close_buf(AVIOContext *s);
* @param s new IO context
* @return zero if no error.
*/
-int url_open_dyn_buf(AVIOContext **s);
+int avio_open_dyn_buf(AVIOContext **s);
/**
* Open a write only packetized memory stream with a maximum packet
@@ -696,7 +697,7 @@ int url_open_dyn_packet_buf(AVIOContext **s, int max_packet_size);
/**
* Return the written size and a pointer to the buffer. The buffer
* must be freed with av_free(). If the buffer is opened with
* url_open_dyn_buf, then padding of FF_INPUT_BUFFER_PADDING_SIZE is
* added; if opened with url_open_dyn_packet_buf, no padding is added.
*
* @param s IO context
@@ -696,7 +697,7 @@ int url_open_dyn_packet_buf(AVIOContext **s, int max_packet_size);
* Return the written size and a pointer to the buffer. The buffer
* must be freed with av_free(). If the buffer is opened with
- * url_open_dyn_buf, then padding of FF_INPUT_BUFFER_PADDING_SIZE is
+ * avio_open_dyn_buf, then padding of FF_INPUT_BUFFER_PADDING_SIZE is
* added; if opened with url_open_dyn_packet_buf, no padding is added.
*